[![Build Status](https://travis-ci.org/konstantinfarrell/sitemap3.svg?branch=develop)](https://travis-ci.org/konstantinfarrell/sitemap3)
[![Coverage Status](https://coveralls.io/repos/github/konstantinfarrell/sitemap3/badge.svg?branch=develop)](https://coveralls.io/github/konstantinfarrell/sitemap3?branch=develop)

# Sitemap3

Sitemap3 is a basic sitemap generation utility written in Python 3.5.

## Install

    pip install sitemap3

or

    git clone git@github.com:konstantinfarrell/sitemap3.git
    cd sitemap3
    python setup.py install

Don't forget a virtualenv

## Usage

    python sitemap <url>

## TODO

- Add xml support
- Add full async support
